complete -c sn0int -n "__fish_use_subcommand" -s w -l workspace -d 'Select a different workspace instead of the default' -r
complete -c sn0int -n "__fish_use_subcommand" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_use_subcommand" -s V -l version -d 'Print version'
complete -c sn0int -n "__fish_use_subcommand" -f -a "run" -d 'Run a module directly'
complete -c sn0int -n "__fish_use_subcommand" -f -a "sandbox" -d 'For internal use'
complete -c sn0int -n "__fish_use_subcommand" -f -a "login" -d 'Login to the registry for publishing'
complete -c sn0int -n "__fish_use_subcommand" -f -a "new" -d 'Create a new module'
complete -c sn0int -n "__fish_use_subcommand" -f -a "publish" -d 'Publish a script to the registry'
complete -c sn0int -n "__fish_use_subcommand" -f -a "install" -d 'Install a module from the registry'
complete -c sn0int -n "__fish_use_subcommand" -f -a "search" -d 'Search in the registry'
complete -c sn0int -n "__fish_use_subcommand" -f -a "pkg" -d 'The sn0int package manager'
complete -c sn0int -n "__fish_use_subcommand" -f -a "add" -d 'Insert into the database'
complete -c sn0int -n "__fish_use_subcommand" -f -a "select" -d 'Select from the database'
complete -c sn0int -n "__fish_use_subcommand" -f -a "delete" -d 'Delete from the database'
complete -c sn0int -n "__fish_use_subcommand" -f -a "activity" -d 'Query logged activity'
complete -c sn0int -n "__fish_use_subcommand" -f -a "scope" -d 'Include entities in the scope'
complete -c sn0int -n "__fish_use_subcommand" -f -a "noscope" -d 'Exclude entities from scope'
complete -c sn0int -n "__fish_use_subcommand" -f -a "autoscope" -d 'Manage autoscope rules'
complete -c sn0int -n "__fish_use_subcommand" -f -a "autonoscope" -d 'Manage autonoscope rules'
complete -c sn0int -n "__fish_use_subcommand" -f -a "rescope" -d 'Rescope all entities based on autonoscope rules'
complete -c sn0int -n "__fish_use_subcommand" -f -a "workspace" -d 'Manage workspaces'
complete -c sn0int -n "__fish_use_subcommand" -f -a "cal" -d 'Calendar'
complete -c sn0int -n "__fish_use_subcommand" -f -a "notify" -d 'Notify'
complete -c sn0int -n "__fish_use_subcommand" -f -a "fsck" -d 'Verify blob storage for corrupt and dangling blobs'
complete -c sn0int -n "__fish_use_subcommand" -f -a "export" -d 'Export a workspace for external processing'
complete -c sn0int -n "__fish_use_subcommand" -f -a "stats" -d 'Show statistics about your current workspace'
complete -c sn0int -n "__fish_use_subcommand" -f -a "repl" -d 'Run a lua repl'
complete -c sn0int -n "__fish_use_subcommand" -f -a "paths" -d 'Show paths of various file system locations'
complete -c sn0int -n "__fish_use_subcommand" -f -a "completions" -d 'Generate shell completions'
complete -c sn0int -n "__fish_use_subcommand" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c sn0int -n "__fish_seen_subcommand_from run" -s j -d 'Run investigations concurrently' -r
complete -c sn0int -n "__fish_seen_subcommand_from run" -s X -l proxy -d 'Set a specific socks5 proxy to use' -r
complete -c sn0int -n "__fish_seen_subcommand_from run" -l user-agent -d 'Set a different default user agent' -r
complete -c sn0int -n "__fish_seen_subcommand_from run" -l grant -d 'Automatically grant access to a keyring namespace' -r
complete -c sn0int -n "__fish_seen_subcommand_from run" -s o -l option -d 'Set an option' -r
complete -c sn0int -n "__fish_seen_subcommand_from run" -s t -l target -d 'Narrow down targeted entities' -r
complete -c sn0int -n "__fish_seen_subcommand_from run" -s v -l verbose -d 'Verbose logging, once to print inserts even if they don\'t add new data, twice to activate the debug() function'
complete -c sn0int -n "__fish_seen_subcommand_from run" -s f -l file -d 'Run a module from a path'
complete -c sn0int -n "__fish_seen_subcommand_from run" -l stdin -d 'Expose stdin to modules'
complete -c sn0int -n "__fish_seen_subcommand_from run" -l grant-full-keyring -d 'Automatically grant access to all requested keys'
complete -c sn0int -n "__fish_seen_subcommand_from run" -l deny-keyring -d 'Automatically deny access to all requested keys'
complete -c sn0int -n "__fish_seen_subcommand_from run" -s x -l exit-on-error -d 'Exit on first error and set exit code'
complete -c sn0int -n "__fish_seen_subcommand_from run" -l dump-sandbox-init-msg -d 'Dump the sandbox init message to stdout instead of running a child process'
complete -c sn0int -n "__fish_seen_subcommand_from run" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from sandbox" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from login" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from new" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from publish" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from install" -s f -l force
complete -c sn0int -n "__fish_seen_subcommand_from install" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from search" -l new -d 'Only show modules that aren\'t installed yet'
complete -c sn0int -n "__fish_seen_subcommand_from search" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from pkg; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from uninstall; and not __fish_seen_subcommand_from quickstart; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from pkg; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from uninstall; and not __fish_seen_subcommand_from quickstart; and not __fish_seen_subcommand_from help" -f -a "list" -d 'List installed modules'
complete -c sn0int -n "__fish_seen_subcommand_from pkg; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from uninstall; and not __fish_seen_subcommand_from quickstart; and not __fish_seen_subcommand_from help" -f -a "install" -d 'Install module from registry'
complete -c sn0int -n "__fish_seen_subcommand_from pkg; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from uninstall; and not __fish_seen_subcommand_from quickstart; and not __fish_seen_subcommand_from help" -f -a "search" -d 'Search modules in registry'
complete -c sn0int -n "__fish_seen_subcommand_from pkg; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from uninstall; and not __fish_seen_subcommand_from quickstart; and not __fish_seen_subcommand_from help" -f -a "update" -d 'Update modules'
complete -c sn0int -n "__fish_seen_subcommand_from pkg; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from uninstall; and not __fish_seen_subcommand_from quickstart; and not __fish_seen_subcommand_from help" -f -a "uninstall" -d 'Uninstall a module'
complete -c sn0int -n "__fish_seen_subcommand_from pkg; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from uninstall; and not __fish_seen_subcommand_from quickstart; and not __fish_seen_subcommand_from help" -f -a "quickstart" -d 'Install all featured modules'
complete -c sn0int -n "__fish_seen_subcommand_from pkg; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from uninstall; and not __fish_seen_subcommand_from quickstart; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c sn0int -n "__fish_seen_subcommand_from pkg; and __fish_seen_subcommand_from list" -l source -d 'Only show modules with a specific input source' -r
complete -c sn0int -n "__fish_seen_subcommand_from pkg; and __fish_seen_subcommand_from list" -l stealth -d 'Only show modules with equal or better stealth level' -r -f -a "{loud	'',normal	'',passive	'',offline	''}"
complete -c sn0int -n "__fish_seen_subcommand_from pkg; and __fish_seen_subcommand_from list" -l outdated -d 'List outdated modules'
complete -c sn0int -n "__fish_seen_subcommand_from pkg; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from pkg; and __fish_seen_subcommand_from install" -s f -l force
complete -c sn0int -n "__fish_seen_subcommand_from pkg; and __fish_seen_subcommand_from install" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from pkg; and __fish_seen_subcommand_from search" -l new -d 'Only show modules that aren\'t installed yet'
complete -c sn0int -n "__fish_seen_subcommand_from pkg; and __fish_seen_subcommand_from search" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from pkg; and __fish_seen_subcommand_from update" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from pkg; and __fish_seen_subcommand_from uninstall" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from pkg; and __fish_seen_subcommand_from quickstart" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from pkg; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from uninstall; and not __fish_seen_subcommand_from quickstart; and not __fish_seen_subcommand_from help" -f -a "list" -d 'List installed modules'
complete -c sn0int -n "__fish_seen_subcommand_from pkg; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from uninstall; and not __fish_seen_subcommand_from quickstart; and not __fish_seen_subcommand_from help" -f -a "install" -d 'Install module from registry'
complete -c sn0int -n "__fish_seen_subcommand_from pkg; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from uninstall; and not __fish_seen_subcommand_from quickstart; and not __fish_seen_subcommand_from help" -f -a "search" -d 'Search modules in registry'
complete -c sn0int -n "__fish_seen_subcommand_from pkg; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from uninstall; and not __fish_seen_subcommand_from quickstart; and not __fish_seen_subcommand_from help" -f -a "update" -d 'Update modules'
complete -c sn0int -n "__fish_seen_subcommand_from pkg; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from uninstall; and not __fish_seen_subcommand_from quickstart; and not __fish_seen_subcommand_from help" -f -a "uninstall" -d 'Uninstall a module'
complete -c sn0int -n "__fish_seen_subcommand_from pkg; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from uninstall; and not __fish_seen_subcommand_from quickstart; and not __fish_seen_subcommand_from help" -f -a "quickstart" -d 'Install all featured modules'
complete -c sn0int -n "__fish_seen_subcommand_from pkg; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from uninstall; and not __fish_seen_subcommand_from quickstart; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c sn0int -n "__fish_seen_subcommand_from add; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr; and not __fish_seen_subcommand_from help" -s n -l dry-run -d 'Do not actually insert into database'
complete -c sn0int -n "__fish_seen_subcommand_from add; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr; and not __fish_seen_subcommand_from help" -l stdin -d 'Stream structs from stdin line by line'
complete -c sn0int -n "__fish_seen_subcommand_from add; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from add; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr; and not __fish_seen_subcommand_from help" -f -a "domain" -d 'Insert domain into the database'
complete -c sn0int -n "__fish_seen_subcommand_from add; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr; and not __fish_seen_subcommand_from help" -f -a "subdomain" -d 'Insert subdomain into the database'
complete -c sn0int -n "__fish_seen_subcommand_from add; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr; and not __fish_seen_subcommand_from help" -f -a "ipaddr" -d 'Insert ip address into the database'
complete -c sn0int -n "__fish_seen_subcommand_from add; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr; and not __fish_seen_subcommand_from help" -f -a "url" -d 'Insert url into the database'
complete -c sn0int -n "__fish_seen_subcommand_from add; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr; and not __fish_seen_subcommand_from help" -f -a "email" -d 'Insert email into the database'
complete -c sn0int -n "__fish_seen_subcommand_from add; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr; and not __fish_seen_subcommand_from help" -f -a "phonenumber" -d 'Insert phonenumber into the database'
complete -c sn0int -n "__fish_seen_subcommand_from add; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr; and not __fish_seen_subcommand_from help" -f -a "device" -d 'Insert device into the database'
complete -c sn0int -n "__fish_seen_subcommand_from add; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr; and not __fish_seen_subcommand_from help" -f -a "network" -d 'Insert network into the database'
complete -c sn0int -n "__fish_seen_subcommand_from add; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr; and not __fish_seen_subcommand_from help" -f -a "account" -d 'Insert account into the database'
complete -c sn0int -n "__fish_seen_subcommand_from add; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr; and not __fish_seen_subcommand_from help" -f -a "breach" -d 'Insert breach into the database'
complete -c sn0int -n "__fish_seen_subcommand_from add; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr; and not __fish_seen_subcommand_from help" -f -a "image" -d 'Insert images into the database'
complete -c sn0int -n "__fish_seen_subcommand_from add; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr; and not __fish_seen_subcommand_from help" -f -a "netblock" -d 'Insert ip network into the database'
complete -c sn0int -n "__fish_seen_subcommand_from add; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr; and not __fish_seen_subcommand_from help" -f -a "port" -d 'Insert port into the database'
complete -c sn0int -n "__fish_seen_subcommand_from add; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr; and not __fish_seen_subcommand_from help" -f -a "cryptoaddr" -d 'Insert a crypto currency address into the database'
complete -c sn0int -n "__fish_seen_subcommand_from add; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c sn0int -n "__fish_seen_subcommand_from add; and __fish_seen_subcommand_from domain" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from add; and __fish_seen_subcommand_from subdomain" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from add; and __fish_seen_subcommand_from ipaddr" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from add; and __fish_seen_subcommand_from url" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from add; and __fish_seen_subcommand_from email" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from add; and __fish_seen_subcommand_from phonenumber" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from add; and __fish_seen_subcommand_from device" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from add; and __fish_seen_subcommand_from network" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from add; and __fish_seen_subcommand_from account" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from add; and __fish_seen_subcommand_from breach" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from add; and __fish_seen_subcommand_from image" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from add; and __fish_seen_subcommand_from netblock" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from add; and __fish_seen_subcommand_from port" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from add; and __fish_seen_subcommand_from cryptoaddr" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from add; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr; and not __fish_seen_subcommand_from help" -f -a "domain" -d 'Insert domain into the database'
complete -c sn0int -n "__fish_seen_subcommand_from add; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr; and not __fish_seen_subcommand_from help" -f -a "subdomain" -d 'Insert subdomain into the database'
complete -c sn0int -n "__fish_seen_subcommand_from add; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr; and not __fish_seen_subcommand_from help" -f -a "ipaddr" -d 'Insert ip address into the database'
complete -c sn0int -n "__fish_seen_subcommand_from add; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr; and not __fish_seen_subcommand_from help" -f -a "url" -d 'Insert url into the database'
complete -c sn0int -n "__fish_seen_subcommand_from add; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr; and not __fish_seen_subcommand_from help" -f -a "email" -d 'Insert email into the database'
complete -c sn0int -n "__fish_seen_subcommand_from add; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr; and not __fish_seen_subcommand_from help" -f -a "phonenumber" -d 'Insert phonenumber into the database'
complete -c sn0int -n "__fish_seen_subcommand_from add; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr; and not __fish_seen_subcommand_from help" -f -a "device" -d 'Insert device into the database'
complete -c sn0int -n "__fish_seen_subcommand_from add; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr; and not __fish_seen_subcommand_from help" -f -a "network" -d 'Insert network into the database'
complete -c sn0int -n "__fish_seen_subcommand_from add; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr; and not __fish_seen_subcommand_from help" -f -a "account" -d 'Insert account into the database'
complete -c sn0int -n "__fish_seen_subcommand_from add; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr; and not __fish_seen_subcommand_from help" -f -a "breach" -d 'Insert breach into the database'
complete -c sn0int -n "__fish_seen_subcommand_from add; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr; and not __fish_seen_subcommand_from help" -f -a "image" -d 'Insert images into the database'
complete -c sn0int -n "__fish_seen_subcommand_from add; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr; and not __fish_seen_subcommand_from help" -f -a "netblock" -d 'Insert ip network into the database'
complete -c sn0int -n "__fish_seen_subcommand_from add; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr; and not __fish_seen_subcommand_from help" -f -a "port" -d 'Insert port into the database'
complete -c sn0int -n "__fish_seen_subcommand_from add; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr; and not __fish_seen_subcommand_from help" -f -a "cryptoaddr" -d 'Insert a crypto currency address into the database'
complete -c sn0int -n "__fish_seen_subcommand_from add; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c sn0int -n "__fish_seen_subcommand_from select; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -l json -d 'Print json output'
complete -c sn0int -n "__fish_seen_subcommand_from select; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -l values -d 'Only print the value instead of the whole object'
complete -c sn0int -n "__fish_seen_subcommand_from select; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -l paths -d 'Print paths to blobs'
complete -c sn0int -n "__fish_seen_subcommand_from select; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -s c -d 'Count rows returned'
complete -c sn0int -n "__fish_seen_subcommand_from select; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from select; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "domains" -d 'On domains'
complete -c sn0int -n "__fish_seen_subcommand_from select; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "subdomains" -d 'On subdomains'
complete -c sn0int -n "__fish_seen_subcommand_from select; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "ipaddrs" -d 'On ipaddrs'
complete -c sn0int -n "__fish_seen_subcommand_from select; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "urls" -d 'On urls'
complete -c sn0int -n "__fish_seen_subcommand_from select; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "emails" -d 'On emails'
complete -c sn0int -n "__fish_seen_subcommand_from select; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "phonenumbers" -d 'On phone numbers'
complete -c sn0int -n "__fish_seen_subcommand_from select; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "devices" -d 'On devices'
complete -c sn0int -n "__fish_seen_subcommand_from select; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "networks" -d 'On networks'
complete -c sn0int -n "__fish_seen_subcommand_from select; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "accounts" -d 'On accounts'
complete -c sn0int -n "__fish_seen_subcommand_from select; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "breaches" -d 'On breaches'
complete -c sn0int -n "__fish_seen_subcommand_from select; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "images" -d 'On images'
complete -c sn0int -n "__fish_seen_subcommand_from select; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "ports" -d 'On ports'
complete -c sn0int -n "__fish_seen_subcommand_from select; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "netblocks" -d 'On ipnets'
complete -c sn0int -n "__fish_seen_subcommand_from select; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "cryptoaddrs" -d 'On crypto currency addresses'
complete -c sn0int -n "__fish_seen_subcommand_from select; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c sn0int -n "__fish_seen_subcommand_from select; and __fish_seen_subcommand_from domains" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from select; and __fish_seen_subcommand_from subdomains" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from select; and __fish_seen_subcommand_from ipaddrs" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from select; and __fish_seen_subcommand_from urls" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from select; and __fish_seen_subcommand_from emails" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from select; and __fish_seen_subcommand_from phonenumbers" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from select; and __fish_seen_subcommand_from devices" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from select; and __fish_seen_subcommand_from networks" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from select; and __fish_seen_subcommand_from accounts" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from select; and __fish_seen_subcommand_from breaches" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from select; and __fish_seen_subcommand_from images" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from select; and __fish_seen_subcommand_from ports" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from select; and __fish_seen_subcommand_from netblocks" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from select; and __fish_seen_subcommand_from cryptoaddrs" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from select; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "domains" -d 'On domains'
complete -c sn0int -n "__fish_seen_subcommand_from select; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "subdomains" -d 'On subdomains'
complete -c sn0int -n "__fish_seen_subcommand_from select; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "ipaddrs" -d 'On ipaddrs'
complete -c sn0int -n "__fish_seen_subcommand_from select; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "urls" -d 'On urls'
complete -c sn0int -n "__fish_seen_subcommand_from select; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "emails" -d 'On emails'
complete -c sn0int -n "__fish_seen_subcommand_from select; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "phonenumbers" -d 'On phone numbers'
complete -c sn0int -n "__fish_seen_subcommand_from select; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "devices" -d 'On devices'
complete -c sn0int -n "__fish_seen_subcommand_from select; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "networks" -d 'On networks'
complete -c sn0int -n "__fish_seen_subcommand_from select; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "accounts" -d 'On accounts'
complete -c sn0int -n "__fish_seen_subcommand_from select; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "breaches" -d 'On breaches'
complete -c sn0int -n "__fish_seen_subcommand_from select; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "images" -d 'On images'
complete -c sn0int -n "__fish_seen_subcommand_from select; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "ports" -d 'On ports'
complete -c sn0int -n "__fish_seen_subcommand_from select; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "netblocks" -d 'On ipnets'
complete -c sn0int -n "__fish_seen_subcommand_from select; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "cryptoaddrs" -d 'On crypto currency addresses'
complete -c sn0int -n "__fish_seen_subcommand_from select; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "domains" -d 'On domains'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "subdomains" -d 'On subdomains'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "ipaddrs" -d 'On ipaddrs'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "urls" -d 'On urls'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "emails" -d 'On emails'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "phonenumbers" -d 'On phone numbers'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "devices" -d 'On devices'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "networks" -d 'On networks'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "accounts" -d 'On accounts'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "breaches" -d 'On breaches'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "images" -d 'On images'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "ports" -d 'On ports'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "netblocks" -d 'On ipnets'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "cryptoaddrs" -d 'On crypto currency addresses'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and __fish_seen_subcommand_from domains" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and __fish_seen_subcommand_from subdomains" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and __fish_seen_subcommand_from ipaddrs" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and __fish_seen_subcommand_from urls" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and __fish_seen_subcommand_from emails" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and __fish_seen_subcommand_from phonenumbers" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and __fish_seen_subcommand_from devices" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and __fish_seen_subcommand_from networks" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and __fish_seen_subcommand_from accounts" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and __fish_seen_subcommand_from breaches" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and __fish_seen_subcommand_from images" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and __fish_seen_subcommand_from ports" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and __fish_seen_subcommand_from netblocks" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and __fish_seen_subcommand_from cryptoaddrs" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "domains" -d 'On domains'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "subdomains" -d 'On subdomains'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "ipaddrs" -d 'On ipaddrs'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "urls" -d 'On urls'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "emails" -d 'On emails'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "phonenumbers" -d 'On phone numbers'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "devices" -d 'On devices'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "networks" -d 'On networks'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "accounts" -d 'On accounts'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "breaches" -d 'On breaches'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "images" -d 'On images'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "ports" -d 'On ports'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "netblocks" -d 'On ipnets'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "cryptoaddrs" -d 'On crypto currency addresses'
complete -c sn0int -n "__fish_seen_subcommand_from delete; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c sn0int -n "__fish_seen_subcommand_from activity" -s t -l topic -d 'Only query events for a given topic' -r
complete -c sn0int -n "__fish_seen_subcommand_from activity" -l since -d 'Only query events starting from that datetime' -r
complete -c sn0int -n "__fish_seen_subcommand_from activity" -l until -d 'Only query events until this datetime' -r
complete -c sn0int -n "__fish_seen_subcommand_from activity" -s i -l initial -d 'Try to select the previous event before --since as an initial state'
complete -c sn0int -n "__fish_seen_subcommand_from activity" -s l -l location -d 'Only query events that are tied to a location'
complete -c sn0int -n "__fish_seen_subcommand_from activity" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "domains" -d 'On domains'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "subdomains" -d 'On subdomains'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "ipaddrs" -d 'On ipaddrs'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "urls" -d 'On urls'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "emails" -d 'On emails'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "phonenumbers" -d 'On phone numbers'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "devices" -d 'On devices'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "networks" -d 'On networks'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "accounts" -d 'On accounts'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "breaches" -d 'On breaches'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "images" -d 'On images'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "ports" -d 'On ports'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "netblocks" -d 'On ipnets'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "cryptoaddrs" -d 'On crypto currency addresses'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and __fish_seen_subcommand_from domains" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and __fish_seen_subcommand_from subdomains" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and __fish_seen_subcommand_from ipaddrs" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and __fish_seen_subcommand_from urls" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and __fish_seen_subcommand_from emails" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and __fish_seen_subcommand_from phonenumbers" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and __fish_seen_subcommand_from devices" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and __fish_seen_subcommand_from networks" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and __fish_seen_subcommand_from accounts" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and __fish_seen_subcommand_from breaches" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and __fish_seen_subcommand_from images" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and __fish_seen_subcommand_from ports" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and __fish_seen_subcommand_from netblocks" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and __fish_seen_subcommand_from cryptoaddrs" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "domains" -d 'On domains'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "subdomains" -d 'On subdomains'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "ipaddrs" -d 'On ipaddrs'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "urls" -d 'On urls'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "emails" -d 'On emails'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "phonenumbers" -d 'On phone numbers'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "devices" -d 'On devices'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "networks" -d 'On networks'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "accounts" -d 'On accounts'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "breaches" -d 'On breaches'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "images" -d 'On images'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "ports" -d 'On ports'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "netblocks" -d 'On ipnets'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "cryptoaddrs" -d 'On crypto currency addresses'
complete -c sn0int -n "__fish_seen_subcommand_from scope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "domains" -d 'On domains'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "subdomains" -d 'On subdomains'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "ipaddrs" -d 'On ipaddrs'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "urls" -d 'On urls'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "emails" -d 'On emails'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "phonenumbers" -d 'On phone numbers'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "devices" -d 'On devices'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "networks" -d 'On networks'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "accounts" -d 'On accounts'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "breaches" -d 'On breaches'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "images" -d 'On images'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "ports" -d 'On ports'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "netblocks" -d 'On ipnets'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "cryptoaddrs" -d 'On crypto currency addresses'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and __fish_seen_subcommand_from domains" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and __fish_seen_subcommand_from subdomains" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and __fish_seen_subcommand_from ipaddrs" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and __fish_seen_subcommand_from urls" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and __fish_seen_subcommand_from emails" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and __fish_seen_subcommand_from phonenumbers" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and __fish_seen_subcommand_from devices" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and __fish_seen_subcommand_from networks" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and __fish_seen_subcommand_from accounts" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and __fish_seen_subcommand_from breaches" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and __fish_seen_subcommand_from images" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and __fish_seen_subcommand_from ports" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and __fish_seen_subcommand_from netblocks" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and __fish_seen_subcommand_from cryptoaddrs" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "domains" -d 'On domains'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "subdomains" -d 'On subdomains'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "ipaddrs" -d 'On ipaddrs'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "urls" -d 'On urls'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "emails" -d 'On emails'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "phonenumbers" -d 'On phone numbers'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "devices" -d 'On devices'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "networks" -d 'On networks'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "accounts" -d 'On accounts'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "breaches" -d 'On breaches'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "images" -d 'On images'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "ports" -d 'On ports'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "netblocks" -d 'On ipnets'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "cryptoaddrs" -d 'On crypto currency addresses'
complete -c sn0int -n "__fish_seen_subcommand_from noscope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c sn0int -n "__fish_seen_subcommand_from autoscope; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from autoscope; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from help" -f -a "add"
complete -c sn0int -n "__fish_seen_subcommand_from autoscope; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from help" -f -a "delete"
complete -c sn0int -n "__fish_seen_subcommand_from autoscope; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from help" -f -a "list"
complete -c sn0int -n "__fish_seen_subcommand_from autoscope; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c sn0int -n "__fish_seen_subcommand_from autoscope; and __fish_seen_subcommand_from add" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from autoscope; and __fish_seen_subcommand_from delete" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from autoscope; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from autoscope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from help" -f -a "add"
complete -c sn0int -n "__fish_seen_subcommand_from autoscope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from help" -f -a "delete"
complete -c sn0int -n "__fish_seen_subcommand_from autoscope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from help" -f -a "list"
complete -c sn0int -n "__fish_seen_subcommand_from autoscope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c sn0int -n "__fish_seen_subcommand_from autonoscope; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from autonoscope; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from help" -f -a "add"
complete -c sn0int -n "__fish_seen_subcommand_from autonoscope; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from help" -f -a "delete"
complete -c sn0int -n "__fish_seen_subcommand_from autonoscope; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from help" -f -a "list"
complete -c sn0int -n "__fish_seen_subcommand_from autonoscope; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c sn0int -n "__fish_seen_subcommand_from autonoscope; and __fish_seen_subcommand_from add" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from autonoscope; and __fish_seen_subcommand_from delete" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from autonoscope; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from autonoscope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from help" -f -a "add"
complete -c sn0int -n "__fish_seen_subcommand_from autonoscope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from help" -f -a "delete"
complete -c sn0int -n "__fish_seen_subcommand_from autonoscope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from help" -f -a "list"
complete -c sn0int -n "__fish_seen_subcommand_from autonoscope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -s i -l interactive -d 'Run rules interactively'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -s y -l auto-confirm -d 'Automatically apply changes to database'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -s n -l dry-run -d 'Only show changes, do not apply them to the database'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "domains" -d 'On domains'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "subdomains" -d 'On subdomains'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "ipaddrs" -d 'On ipaddrs'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "urls" -d 'On urls'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "emails" -d 'On emails'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "phonenumbers" -d 'On phone numbers'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "devices" -d 'On devices'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "networks" -d 'On networks'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "accounts" -d 'On accounts'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "breaches" -d 'On breaches'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "images" -d 'On images'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "ports" -d 'On ports'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "netblocks" -d 'On ipnets'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "cryptoaddrs" -d 'On crypto currency addresses'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and __fish_seen_subcommand_from domains" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and __fish_seen_subcommand_from subdomains" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and __fish_seen_subcommand_from ipaddrs" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and __fish_seen_subcommand_from urls" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and __fish_seen_subcommand_from emails" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and __fish_seen_subcommand_from phonenumbers" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and __fish_seen_subcommand_from devices" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and __fish_seen_subcommand_from networks" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and __fish_seen_subcommand_from accounts" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and __fish_seen_subcommand_from breaches" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and __fish_seen_subcommand_from images" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and __fish_seen_subcommand_from ports" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and __fish_seen_subcommand_from netblocks" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and __fish_seen_subcommand_from cryptoaddrs" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "domains" -d 'On domains'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "subdomains" -d 'On subdomains'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "ipaddrs" -d 'On ipaddrs'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "urls" -d 'On urls'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "emails" -d 'On emails'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "phonenumbers" -d 'On phone numbers'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "devices" -d 'On devices'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "networks" -d 'On networks'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "accounts" -d 'On accounts'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "breaches" -d 'On breaches'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "images" -d 'On images'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "ports" -d 'On ports'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "netblocks" -d 'On ipnets'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "cryptoaddrs" -d 'On crypto currency addresses'
complete -c sn0int -n "__fish_seen_subcommand_from rescope; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c sn0int -n "__fish_seen_subcommand_from workspace" -l delete -d 'Delete a workspaceb'
complete -c sn0int -n "__fish_seen_subcommand_from workspace" -l usage -d 'Show disk usage of workspace'
complete -c sn0int -n "__fish_seen_subcommand_from workspace" -s f -l force -d 'Skip confirmation'
complete -c sn0int -n "__fish_seen_subcommand_from workspace" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from cal" -s C -l context -d 'Show additional months for context' -r
complete -c sn0int -n "__fish_seen_subcommand_from cal" -s T -l time -d 'Group events in 12 min slices'
complete -c sn0int -n "__fish_seen_subcommand_from cal" -s H -l hourly -d 'Group events by hour'
complete -c sn0int -n "__fish_seen_subcommand_from cal" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from notify; and not __fish_seen_subcommand_from send; and not __fish_seen_subcommand_from outbox; and not __fish_seen_subcommand_from exec; and not __fish_seen_subcommand_from deliver; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from notify; and not __fish_seen_subcommand_from send; and not __fish_seen_subcommand_from outbox; and not __fish_seen_subcommand_from exec; and not __fish_seen_subcommand_from deliver; and not __fish_seen_subcommand_from help" -f -a "send" -d 'Manually add a notification to the outbox'
complete -c sn0int -n "__fish_seen_subcommand_from notify; and not __fish_seen_subcommand_from send; and not __fish_seen_subcommand_from outbox; and not __fish_seen_subcommand_from exec; and not __fish_seen_subcommand_from deliver; and not __fish_seen_subcommand_from help" -f -a "outbox" -d 'Show the current outbox'
complete -c sn0int -n "__fish_seen_subcommand_from notify; and not __fish_seen_subcommand_from send; and not __fish_seen_subcommand_from outbox; and not __fish_seen_subcommand_from exec; and not __fish_seen_subcommand_from deliver; and not __fish_seen_subcommand_from help" -f -a "exec" -d 'Execute a module directly instead of sending a message'
complete -c sn0int -n "__fish_seen_subcommand_from notify; and not __fish_seen_subcommand_from send; and not __fish_seen_subcommand_from outbox; and not __fish_seen_subcommand_from exec; and not __fish_seen_subcommand_from deliver; and not __fish_seen_subcommand_from help" -f -a "deliver" -d 'Try to deliver all messages in our outbox'
complete -c sn0int -n "__fish_seen_subcommand_from notify; and not __fish_seen_subcommand_from send; and not __fish_seen_subcommand_from outbox; and not __fish_seen_subcommand_from exec; and not __fish_seen_subcommand_from deliver; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c sn0int -n "__fish_seen_subcommand_from notify; and __fish_seen_subcommand_from send" -s n -l dry-run -d 'Evaluate the routing rules, but do not actually send a notification'
complete -c sn0int -n "__fish_seen_subcommand_from notify; and __fish_seen_subcommand_from send" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from notify; and __fish_seen_subcommand_from outbox" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from notify; and __fish_seen_subcommand_from exec" -s o -l option -r
complete -c sn0int -n "__fish_seen_subcommand_from notify; and __fish_seen_subcommand_from exec" -s v -l verbose
complete -c sn0int -n "__fish_seen_subcommand_from notify; and __fish_seen_subcommand_from exec" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from notify; and __fish_seen_subcommand_from deliver" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from notify; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from send; and not __fish_seen_subcommand_from outbox; and not __fish_seen_subcommand_from exec; and not __fish_seen_subcommand_from deliver; and not __fish_seen_subcommand_from help" -f -a "send" -d 'Manually add a notification to the outbox'
complete -c sn0int -n "__fish_seen_subcommand_from notify; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from send; and not __fish_seen_subcommand_from outbox; and not __fish_seen_subcommand_from exec; and not __fish_seen_subcommand_from deliver; and not __fish_seen_subcommand_from help" -f -a "outbox" -d 'Show the current outbox'
complete -c sn0int -n "__fish_seen_subcommand_from notify; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from send; and not __fish_seen_subcommand_from outbox; and not __fish_seen_subcommand_from exec; and not __fish_seen_subcommand_from deliver; and not __fish_seen_subcommand_from help" -f -a "exec" -d 'Execute a module directly instead of sending a message'
complete -c sn0int -n "__fish_seen_subcommand_from notify; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from send; and not __fish_seen_subcommand_from outbox; and not __fish_seen_subcommand_from exec; and not __fish_seen_subcommand_from deliver; and not __fish_seen_subcommand_from help" -f -a "deliver" -d 'Try to deliver all messages in our outbox'
complete -c sn0int -n "__fish_seen_subcommand_from notify; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from send; and not __fish_seen_subcommand_from outbox; and not __fish_seen_subcommand_from exec; and not __fish_seen_subcommand_from deliver; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c sn0int -n "__fish_seen_subcommand_from fsck" -s v -l verbose -d 'Verbose output'
complete -c sn0int -n "__fish_seen_subcommand_from fsck" -l gc -d 'Delete only dangling blobs'
complete -c sn0int -n "__fish_seen_subcommand_from fsck" -l gc-all -d 'Delete dangling and corrupted blobs'
complete -c sn0int -n "__fish_seen_subcommand_from fsck" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from export" -s f -l format -d 'Specify the export format' -r -f -a "{json	'',json-blobs	''}"
complete -c sn0int -n "__fish_seen_subcommand_from export" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from stats" -s s -l short -d 'Exclude blob storage'
complete -c sn0int -n "__fish_seen_subcommand_from stats" -s q -l quiet -d 'Exclude categories that don\'t contain any structs'
complete -c sn0int -n "__fish_seen_subcommand_from stats" -s j -l json -d 'Show workspace statistics in json'
complete -c sn0int -n "__fish_seen_subcommand_from stats" -s a -l all -d 'Go through all workspaces'
complete -c sn0int -n "__fish_seen_subcommand_from stats" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from repl" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from paths" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from completions" -s h -l help -d 'Print help'
complete -c sn0int -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from run; and not __fish_seen_subcommand_from sandbox; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from new; and not __fish_seen_subcommand_from publish; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from pkg; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from select; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from activity; and not __fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from autoscope; and not __fish_seen_subcommand_from autonoscope; and not __fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from workspace; and not __fish_seen_subcommand_from cal; and not __fish_seen_subcommand_from notify; and not __fish_seen_subcommand_from fsck; and not __fish_seen_subcommand_from export; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from repl; and not __fish_seen_subcommand_from paths; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from help" -f -a "run" -d 'Run a module directly'
complete -c sn0int -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from run; and not __fish_seen_subcommand_from sandbox; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from new; and not __fish_seen_subcommand_from publish; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from pkg; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from select; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from activity; and not __fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from autoscope; and not __fish_seen_subcommand_from autonoscope; and not __fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from workspace; and not __fish_seen_subcommand_from cal; and not __fish_seen_subcommand_from notify; and not __fish_seen_subcommand_from fsck; and not __fish_seen_subcommand_from export; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from repl; and not __fish_seen_subcommand_from paths; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from help" -f -a "sandbox" -d 'For internal use'
complete -c sn0int -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from run; and not __fish_seen_subcommand_from sandbox; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from new; and not __fish_seen_subcommand_from publish; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from pkg; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from select; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from activity; and not __fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from autoscope; and not __fish_seen_subcommand_from autonoscope; and not __fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from workspace; and not __fish_seen_subcommand_from cal; and not __fish_seen_subcommand_from notify; and not __fish_seen_subcommand_from fsck; and not __fish_seen_subcommand_from export; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from repl; and not __fish_seen_subcommand_from paths; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from help" -f -a "login" -d 'Login to the registry for publishing'
complete -c sn0int -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from run; and not __fish_seen_subcommand_from sandbox; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from new; and not __fish_seen_subcommand_from publish; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from pkg; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from select; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from activity; and not __fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from autoscope; and not __fish_seen_subcommand_from autonoscope; and not __fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from workspace; and not __fish_seen_subcommand_from cal; and not __fish_seen_subcommand_from notify; and not __fish_seen_subcommand_from fsck; and not __fish_seen_subcommand_from export; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from repl; and not __fish_seen_subcommand_from paths; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from help" -f -a "new" -d 'Create a new module'
complete -c sn0int -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from run; and not __fish_seen_subcommand_from sandbox; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from new; and not __fish_seen_subcommand_from publish; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from pkg; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from select; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from activity; and not __fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from autoscope; and not __fish_seen_subcommand_from autonoscope; and not __fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from workspace; and not __fish_seen_subcommand_from cal; and not __fish_seen_subcommand_from notify; and not __fish_seen_subcommand_from fsck; and not __fish_seen_subcommand_from export; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from repl; and not __fish_seen_subcommand_from paths; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from help" -f -a "publish" -d 'Publish a script to the registry'
complete -c sn0int -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from run; and not __fish_seen_subcommand_from sandbox; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from new; and not __fish_seen_subcommand_from publish; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from pkg; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from select; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from activity; and not __fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from autoscope; and not __fish_seen_subcommand_from autonoscope; and not __fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from workspace; and not __fish_seen_subcommand_from cal; and not __fish_seen_subcommand_from notify; and not __fish_seen_subcommand_from fsck; and not __fish_seen_subcommand_from export; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from repl; and not __fish_seen_subcommand_from paths; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from help" -f -a "install" -d 'Install a module from the registry'
complete -c sn0int -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from run; and not __fish_seen_subcommand_from sandbox; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from new; and not __fish_seen_subcommand_from publish; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from pkg; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from select; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from activity; and not __fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from autoscope; and not __fish_seen_subcommand_from autonoscope; and not __fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from workspace; and not __fish_seen_subcommand_from cal; and not __fish_seen_subcommand_from notify; and not __fish_seen_subcommand_from fsck; and not __fish_seen_subcommand_from export; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from repl; and not __fish_seen_subcommand_from paths; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from help" -f -a "search" -d 'Search in the registry'
complete -c sn0int -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from run; and not __fish_seen_subcommand_from sandbox; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from new; and not __fish_seen_subcommand_from publish; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from pkg; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from select; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from activity; and not __fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from autoscope; and not __fish_seen_subcommand_from autonoscope; and not __fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from workspace; and not __fish_seen_subcommand_from cal; and not __fish_seen_subcommand_from notify; and not __fish_seen_subcommand_from fsck; and not __fish_seen_subcommand_from export; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from repl; and not __fish_seen_subcommand_from paths; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from help" -f -a "pkg" -d 'The sn0int package manager'
complete -c sn0int -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from run; and not __fish_seen_subcommand_from sandbox; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from new; and not __fish_seen_subcommand_from publish; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from pkg; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from select; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from activity; and not __fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from autoscope; and not __fish_seen_subcommand_from autonoscope; and not __fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from workspace; and not __fish_seen_subcommand_from cal; and not __fish_seen_subcommand_from notify; and not __fish_seen_subcommand_from fsck; and not __fish_seen_subcommand_from export; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from repl; and not __fish_seen_subcommand_from paths; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from help" -f -a "add" -d 'Insert into the database'
complete -c sn0int -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from run; and not __fish_seen_subcommand_from sandbox; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from new; and not __fish_seen_subcommand_from publish; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from pkg; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from select; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from activity; and not __fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from autoscope; and not __fish_seen_subcommand_from autonoscope; and not __fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from workspace; and not __fish_seen_subcommand_from cal; and not __fish_seen_subcommand_from notify; and not __fish_seen_subcommand_from fsck; and not __fish_seen_subcommand_from export; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from repl; and not __fish_seen_subcommand_from paths; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from help" -f -a "select" -d 'Select from the database'
complete -c sn0int -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from run; and not __fish_seen_subcommand_from sandbox; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from new; and not __fish_seen_subcommand_from publish; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from pkg; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from select; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from activity; and not __fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from autoscope; and not __fish_seen_subcommand_from autonoscope; and not __fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from workspace; and not __fish_seen_subcommand_from cal; and not __fish_seen_subcommand_from notify; and not __fish_seen_subcommand_from fsck; and not __fish_seen_subcommand_from export; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from repl; and not __fish_seen_subcommand_from paths; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from help" -f -a "delete" -d 'Delete from the database'
complete -c sn0int -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from run; and not __fish_seen_subcommand_from sandbox; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from new; and not __fish_seen_subcommand_from publish; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from pkg; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from select; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from activity; and not __fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from autoscope; and not __fish_seen_subcommand_from autonoscope; and not __fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from workspace; and not __fish_seen_subcommand_from cal; and not __fish_seen_subcommand_from notify; and not __fish_seen_subcommand_from fsck; and not __fish_seen_subcommand_from export; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from repl; and not __fish_seen_subcommand_from paths; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from help" -f -a "activity" -d 'Query logged activity'
complete -c sn0int -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from run; and not __fish_seen_subcommand_from sandbox; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from new; and not __fish_seen_subcommand_from publish; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from pkg; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from select; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from activity; and not __fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from autoscope; and not __fish_seen_subcommand_from autonoscope; and not __fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from workspace; and not __fish_seen_subcommand_from cal; and not __fish_seen_subcommand_from notify; and not __fish_seen_subcommand_from fsck; and not __fish_seen_subcommand_from export; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from repl; and not __fish_seen_subcommand_from paths; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from help" -f -a "scope" -d 'Include entities in the scope'
complete -c sn0int -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from run; and not __fish_seen_subcommand_from sandbox; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from new; and not __fish_seen_subcommand_from publish; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from pkg; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from select; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from activity; and not __fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from autoscope; and not __fish_seen_subcommand_from autonoscope; and not __fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from workspace; and not __fish_seen_subcommand_from cal; and not __fish_seen_subcommand_from notify; and not __fish_seen_subcommand_from fsck; and not __fish_seen_subcommand_from export; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from repl; and not __fish_seen_subcommand_from paths; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from help" -f -a "noscope" -d 'Exclude entities from scope'
complete -c sn0int -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from run; and not __fish_seen_subcommand_from sandbox; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from new; and not __fish_seen_subcommand_from publish; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from pkg; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from select; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from activity; and not __fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from autoscope; and not __fish_seen_subcommand_from autonoscope; and not __fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from workspace; and not __fish_seen_subcommand_from cal; and not __fish_seen_subcommand_from notify; and not __fish_seen_subcommand_from fsck; and not __fish_seen_subcommand_from export; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from repl; and not __fish_seen_subcommand_from paths; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from help" -f -a "autoscope" -d 'Manage autoscope rules'
complete -c sn0int -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from run; and not __fish_seen_subcommand_from sandbox; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from new; and not __fish_seen_subcommand_from publish; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from pkg; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from select; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from activity; and not __fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from autoscope; and not __fish_seen_subcommand_from autonoscope; and not __fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from workspace; and not __fish_seen_subcommand_from cal; and not __fish_seen_subcommand_from notify; and not __fish_seen_subcommand_from fsck; and not __fish_seen_subcommand_from export; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from repl; and not __fish_seen_subcommand_from paths; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from help" -f -a "autonoscope" -d 'Manage autonoscope rules'
complete -c sn0int -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from run; and not __fish_seen_subcommand_from sandbox; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from new; and not __fish_seen_subcommand_from publish; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from pkg; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from select; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from activity; and not __fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from autoscope; and not __fish_seen_subcommand_from autonoscope; and not __fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from workspace; and not __fish_seen_subcommand_from cal; and not __fish_seen_subcommand_from notify; and not __fish_seen_subcommand_from fsck; and not __fish_seen_subcommand_from export; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from repl; and not __fish_seen_subcommand_from paths; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from help" -f -a "rescope" -d 'Rescope all entities based on autonoscope rules'
complete -c sn0int -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from run; and not __fish_seen_subcommand_from sandbox; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from new; and not __fish_seen_subcommand_from publish; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from pkg; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from select; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from activity; and not __fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from autoscope; and not __fish_seen_subcommand_from autonoscope; and not __fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from workspace; and not __fish_seen_subcommand_from cal; and not __fish_seen_subcommand_from notify; and not __fish_seen_subcommand_from fsck; and not __fish_seen_subcommand_from export; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from repl; and not __fish_seen_subcommand_from paths; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from help" -f -a "workspace" -d 'Manage workspaces'
complete -c sn0int -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from run; and not __fish_seen_subcommand_from sandbox; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from new; and not __fish_seen_subcommand_from publish; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from pkg; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from select; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from activity; and not __fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from autoscope; and not __fish_seen_subcommand_from autonoscope; and not __fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from workspace; and not __fish_seen_subcommand_from cal; and not __fish_seen_subcommand_from notify; and not __fish_seen_subcommand_from fsck; and not __fish_seen_subcommand_from export; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from repl; and not __fish_seen_subcommand_from paths; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from help" -f -a "cal" -d 'Calendar'
complete -c sn0int -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from run; and not __fish_seen_subcommand_from sandbox; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from new; and not __fish_seen_subcommand_from publish; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from pkg; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from select; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from activity; and not __fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from autoscope; and not __fish_seen_subcommand_from autonoscope; and not __fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from workspace; and not __fish_seen_subcommand_from cal; and not __fish_seen_subcommand_from notify; and not __fish_seen_subcommand_from fsck; and not __fish_seen_subcommand_from export; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from repl; and not __fish_seen_subcommand_from paths; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from help" -f -a "notify" -d 'Notify'
complete -c sn0int -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from run; and not __fish_seen_subcommand_from sandbox; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from new; and not __fish_seen_subcommand_from publish; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from pkg; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from select; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from activity; and not __fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from autoscope; and not __fish_seen_subcommand_from autonoscope; and not __fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from workspace; and not __fish_seen_subcommand_from cal; and not __fish_seen_subcommand_from notify; and not __fish_seen_subcommand_from fsck; and not __fish_seen_subcommand_from export; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from repl; and not __fish_seen_subcommand_from paths; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from help" -f -a "fsck" -d 'Verify blob storage for corrupt and dangling blobs'
complete -c sn0int -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from run; and not __fish_seen_subcommand_from sandbox; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from new; and not __fish_seen_subcommand_from publish; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from pkg; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from select; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from activity; and not __fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from autoscope; and not __fish_seen_subcommand_from autonoscope; and not __fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from workspace; and not __fish_seen_subcommand_from cal; and not __fish_seen_subcommand_from notify; and not __fish_seen_subcommand_from fsck; and not __fish_seen_subcommand_from export; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from repl; and not __fish_seen_subcommand_from paths; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from help" -f -a "export" -d 'Export a workspace for external processing'
complete -c sn0int -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from run; and not __fish_seen_subcommand_from sandbox; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from new; and not __fish_seen_subcommand_from publish; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from pkg; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from select; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from activity; and not __fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from autoscope; and not __fish_seen_subcommand_from autonoscope; and not __fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from workspace; and not __fish_seen_subcommand_from cal; and not __fish_seen_subcommand_from notify; and not __fish_seen_subcommand_from fsck; and not __fish_seen_subcommand_from export; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from repl; and not __fish_seen_subcommand_from paths; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from help" -f -a "stats" -d 'Show statistics about your current workspace'
complete -c sn0int -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from run; and not __fish_seen_subcommand_from sandbox; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from new; and not __fish_seen_subcommand_from publish; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from pkg; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from select; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from activity; and not __fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from autoscope; and not __fish_seen_subcommand_from autonoscope; and not __fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from workspace; and not __fish_seen_subcommand_from cal; and not __fish_seen_subcommand_from notify; and not __fish_seen_subcommand_from fsck; and not __fish_seen_subcommand_from export; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from repl; and not __fish_seen_subcommand_from paths; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from help" -f -a "repl" -d 'Run a lua repl'
complete -c sn0int -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from run; and not __fish_seen_subcommand_from sandbox; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from new; and not __fish_seen_subcommand_from publish; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from pkg; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from select; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from activity; and not __fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from autoscope; and not __fish_seen_subcommand_from autonoscope; and not __fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from workspace; and not __fish_seen_subcommand_from cal; and not __fish_seen_subcommand_from notify; and not __fish_seen_subcommand_from fsck; and not __fish_seen_subcommand_from export; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from repl; and not __fish_seen_subcommand_from paths; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from help" -f -a "paths" -d 'Show paths of various file system locations'
complete -c sn0int -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from run; and not __fish_seen_subcommand_from sandbox; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from new; and not __fish_seen_subcommand_from publish; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from pkg; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from select; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from activity; and not __fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from autoscope; and not __fish_seen_subcommand_from autonoscope; and not __fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from workspace; and not __fish_seen_subcommand_from cal; and not __fish_seen_subcommand_from notify; and not __fish_seen_subcommand_from fsck; and not __fish_seen_subcommand_from export; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from repl; and not __fish_seen_subcommand_from paths; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from help" -f -a "completions" -d 'Generate shell completions'
complete -c sn0int -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from run; and not __fish_seen_subcommand_from sandbox; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from new; and not __fish_seen_subcommand_from publish; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from pkg; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from select; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from activity; and not __fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from autoscope; and not __fish_seen_subcommand_from autonoscope; and not __fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from workspace; and not __fish_seen_subcommand_from cal; and not __fish_seen_subcommand_from notify; and not __fish_seen_subcommand_from fsck; and not __fish_seen_subcommand_from export; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from repl; and not __fish_seen_subcommand_from paths; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from pkg; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from uninstall; and not __fish_seen_subcommand_from quickstart" -f -a "list" -d 'List installed modules'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from pkg; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from uninstall; and not __fish_seen_subcommand_from quickstart" -f -a "install" -d 'Install module from registry'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from pkg; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from uninstall; and not __fish_seen_subcommand_from quickstart" -f -a "search" -d 'Search modules in registry'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from pkg; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from uninstall; and not __fish_seen_subcommand_from quickstart" -f -a "update" -d 'Update modules'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from pkg; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from uninstall; and not __fish_seen_subcommand_from quickstart" -f -a "uninstall" -d 'Uninstall a module'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from pkg; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from uninstall; and not __fish_seen_subcommand_from quickstart" -f -a "quickstart" -d 'Install all featured modules'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr" -f -a "domain" -d 'Insert domain into the database'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr" -f -a "subdomain" -d 'Insert subdomain into the database'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr" -f -a "ipaddr" -d 'Insert ip address into the database'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr" -f -a "url" -d 'Insert url into the database'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr" -f -a "email" -d 'Insert email into the database'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr" -f -a "phonenumber" -d 'Insert phonenumber into the database'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr" -f -a "device" -d 'Insert device into the database'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr" -f -a "network" -d 'Insert network into the database'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr" -f -a "account" -d 'Insert account into the database'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr" -f -a "breach" -d 'Insert breach into the database'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr" -f -a "image" -d 'Insert images into the database'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr" -f -a "netblock" -d 'Insert ip network into the database'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr" -f -a "port" -d 'Insert port into the database'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from domain; and not __fish_seen_subcommand_from subdomain; and not __fish_seen_subcommand_from ipaddr; and not __fish_seen_subcommand_from url; and not __fish_seen_subcommand_from email; and not __fish_seen_subcommand_from phonenumber; and not __fish_seen_subcommand_from device; and not __fish_seen_subcommand_from network; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from breach; and not __fish_seen_subcommand_from image; and not __fish_seen_subcommand_from netblock; and not __fish_seen_subcommand_from port; and not __fish_seen_subcommand_from cryptoaddr" -f -a "cryptoaddr" -d 'Insert a crypto currency address into the database'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from select; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "domains" -d 'On domains'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from select; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "subdomains" -d 'On subdomains'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from select; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "ipaddrs" -d 'On ipaddrs'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from select; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "urls" -d 'On urls'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from select; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "emails" -d 'On emails'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from select; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "phonenumbers" -d 'On phone numbers'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from select; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "devices" -d 'On devices'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from select; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "networks" -d 'On networks'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from select; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "accounts" -d 'On accounts'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from select; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "breaches" -d 'On breaches'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from select; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "images" -d 'On images'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from select; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "ports" -d 'On ports'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from select; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "netblocks" -d 'On ipnets'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from select; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "cryptoaddrs" -d 'On crypto currency addresses'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "domains" -d 'On domains'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "subdomains" -d 'On subdomains'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "ipaddrs" -d 'On ipaddrs'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "urls" -d 'On urls'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "emails" -d 'On emails'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "phonenumbers" -d 'On phone numbers'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "devices" -d 'On devices'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "networks" -d 'On networks'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "accounts" -d 'On accounts'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "breaches" -d 'On breaches'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "images" -d 'On images'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "ports" -d 'On ports'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "netblocks" -d 'On ipnets'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "cryptoaddrs" -d 'On crypto currency addresses'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "domains" -d 'On domains'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "subdomains" -d 'On subdomains'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "ipaddrs" -d 'On ipaddrs'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "urls" -d 'On urls'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "emails" -d 'On emails'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "phonenumbers" -d 'On phone numbers'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "devices" -d 'On devices'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "networks" -d 'On networks'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "accounts" -d 'On accounts'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "breaches" -d 'On breaches'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "images" -d 'On images'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "ports" -d 'On ports'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "netblocks" -d 'On ipnets'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from scope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "cryptoaddrs" -d 'On crypto currency addresses'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "domains" -d 'On domains'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "subdomains" -d 'On subdomains'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "ipaddrs" -d 'On ipaddrs'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "urls" -d 'On urls'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "emails" -d 'On emails'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "phonenumbers" -d 'On phone numbers'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "devices" -d 'On devices'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "networks" -d 'On networks'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "accounts" -d 'On accounts'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "breaches" -d 'On breaches'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "images" -d 'On images'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "ports" -d 'On ports'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "netblocks" -d 'On ipnets'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from noscope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "cryptoaddrs" -d 'On crypto currency addresses'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from autoscope; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from list" -f -a "add"
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from autoscope; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from list" -f -a "delete"
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from autoscope; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from list" -f -a "list"
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from autonoscope; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from list" -f -a "add"
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from autonoscope; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from list" -f -a "delete"
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from autonoscope; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from list" -f -a "list"
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "domains" -d 'On domains'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "subdomains" -d 'On subdomains'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "ipaddrs" -d 'On ipaddrs'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "urls" -d 'On urls'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "emails" -d 'On emails'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "phonenumbers" -d 'On phone numbers'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "devices" -d 'On devices'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "networks" -d 'On networks'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "accounts" -d 'On accounts'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "breaches" -d 'On breaches'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "images" -d 'On images'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "ports" -d 'On ports'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "netblocks" -d 'On ipnets'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from rescope; and not __fish_seen_subcommand_from domains; and not __fish_seen_subcommand_from subdomains; and not __fish_seen_subcommand_from ipaddrs; and not __fish_seen_subcommand_from urls; and not __fish_seen_subcommand_from emails; and not __fish_seen_subcommand_from phonenumbers; and not __fish_seen_subcommand_from devices; and not __fish_seen_subcommand_from networks; and not __fish_seen_subcommand_from accounts; and not __fish_seen_subcommand_from breaches; and not __fish_seen_subcommand_from images; and not __fish_seen_subcommand_from ports; and not __fish_seen_subcommand_from netblocks; and not __fish_seen_subcommand_from cryptoaddrs" -f -a "cryptoaddrs" -d 'On crypto currency addresses'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from notify; and not __fish_seen_subcommand_from send; and not __fish_seen_subcommand_from outbox; and not __fish_seen_subcommand_from exec; and not __fish_seen_subcommand_from deliver" -f -a "send" -d 'Manually add a notification to the outbox'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from notify; and not __fish_seen_subcommand_from send; and not __fish_seen_subcommand_from outbox; and not __fish_seen_subcommand_from exec; and not __fish_seen_subcommand_from deliver" -f -a "outbox" -d 'Show the current outbox'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from notify; and not __fish_seen_subcommand_from send; and not __fish_seen_subcommand_from outbox; and not __fish_seen_subcommand_from exec; and not __fish_seen_subcommand_from deliver" -f -a "exec" -d 'Execute a module directly instead of sending a message'
complete -c sn0int -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from notify; and not __fish_seen_subcommand_from send; and not __fish_seen_subcommand_from outbox; and not __fish_seen_subcommand_from exec; and not __fish_seen_subcommand_from deliver" -f -a "deliver" -d 'Try to deliver all messages in our outbox'
